M3ECardPosition enum

The position of a card within a list, used to determine its corner radii.

Inheritance
Available extensions

Values

first → const M3ECardPosition

The first item in a list with more than one item.

middle → const M3ECardPosition

An item between the first and last items.

last → const M3ECardPosition

The last item in a list with more than one item.

single → const M3ECardPosition

The only item in a list.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<M3ECardPosition>
A constant List of the values in this enum, in order of their declaration.