onItemSelected method

void onItemSelected(
  1. int index
)

Called when an item is selected from the overflow menu.

Override to handle the selection, typically by calling the group's selection callback.

Implementation

void onItemSelected(int index) {}