M3EDropdownStyle class
Visual styling for the dropdown panel (the list of items).
- Mixed-in types
- Annotations
Constructors
- M3EDropdownStyle({Color? backgroundColor, double elevation = 3, double maxHeight = 350, double marginTop = 4, String noItemsFoundText = 'No items found', Widget? header, EdgeInsetsGeometry contentPadding = const EdgeInsets.all(8), ExpandDirection expandDirection = ExpandDirection.auto, double? containerRadius})
-
Creates a M3EDropdownStyle.
const
Properties
- backgroundColor → Color?
-
Background color of the dropdown panel.
final
- containerRadius → double?
-
Radius applied to the dropdown panel container.
final
- contentPadding → EdgeInsetsGeometry
-
Padding applied around the item list inside the dropdown panel.
final
- elevation → double
-
Elevation of the dropdown panel.
final
- expandDirection → ExpandDirection
-
The direction in which the dropdown expands.
final
-
An optional footer widget shown below the items.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- header → Widget?
-
An optional header widget shown above the items.
final
- marginTop → double
-
Gap between the field and the dropdown panel.
final
- maxHeight → double
-
Maximum height of the dropdown panel.
final
- noItemsFoundText → String
-
Text shown when search yields no matches.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? backgroundColor, double? elevation, double? maxHeight, double? marginTop, String? noItemsFoundText, Widget? header, EdgeInsetsGeometry? contentPadding, ExpandDirection? expandDirection, double? containerRadius}) → M3EDropdownStyle - Creates a copy of this style with the given fields replaced.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
M3EDropdownStyle? a, M3EDropdownStyle? b, double t) → M3EDropdownStyle - Linearly interpolate between two dropdown styles.