NoOverflowStrategy class
Strategy for no overflow (all buttons always visible).
Use with M3EToggleButtonGroup to disable overflow handling:
M3EToggleButtonGroup(
overflowStrategy: const NoOverflowStrategy(),
)
- Inheritance
-
- Object
- OverflowStrategy
- NoOverflowStrategy
Constructors
- NoOverflowStrategy()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this overflow strategy.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- triggerExtent → double?
-
Returns the estimated main-axis extent of the trigger built by buildOverflowTrigger.
no setterinherited
Methods
-
buildLayout(
{required BuildContext context, required List< M3EToggleButtonGroupAction> actions, required int visibleCount, required double spacing, required Axis direction, required M3EButtonStyle style, required M3EButtonSize size, required M3EToggleButtonDecoration? decoration, required bool connected, required bool isRtl, required Widget buildButton(int index, bool isFirst, bool isLast)}) → Widget -
Builds the main layout of visible buttons.
override
-
buildOverflowTrigger(
{required BuildContext context, required M3EButtonStyle style, required M3EButtonSize size, required M3EToggleButtonDecoration? decoration, required bool connected, required bool isFirst, required bool isLast, required VoidCallback onPressed, required bool checked}) → Widget? -
Builds the overflow trigger widget.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onItemSelected(
int index) → void -
Called when an item is selected from the overflow menu.
inherited
-
showOverflowMenu(
{required BuildContext context, required List< M3EToggleButtonGroupAction> actions, required int firstHiddenIndex, required int? selectedIndex}) → Future<int?> -
Opens the overflow menu when the trigger is pressed.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited