onItemSelected method
Called when an item is selected from the overflow menu.
Override to handle the selection, typically by calling the group's selection callback.
Implementation
void onItemSelected(int index) {}
Called when an item is selected from the overflow menu.
Override to handle the selection, typically by calling the group's selection callback.
void onItemSelected(int index) {}